.. sparc.client documentation master file, created by
   sphinx-quickstart on Wed Mar 15 23:25:48 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sparc.client's documentation!
========================================

A great starting point for using our package could be found in our `tutorial <https://github.com/nih-sparc/sparc.client/blob/main/docs/tutorial.ipynb>`_ .

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   sparc.client

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
